## LinkageMechanism
. Aplicativo Pytho para cálculo de Mecanismos Articulados com um ou mais graus de liberdade.

## Métodos

* `MecSolve_OneDOF([<cords>],[<eq. restrição>])` - Tem as coordenadas generalizadas e a matriz das equqções de restrição como argumentos.
retorna as matrizes F, J, K e L em forma de tupla.

* `MecSolve_MultDOF([<cords>],[<eq. restrição>])` - Tem as coordenadas generalizadas e a matriz das equqções de restrição como argumentos.
retorna as matrizes F, J, K e L em forma de tupla.